@@ -1,7 +1,7 @@
 from .bot import DGGBot
 from .chat import DGGChat
 from .event import EventType
-from .live import DGGLive, StreamInfo, YoutubeVideo, YoutubeVod
+from .live import DGGLive, StreamInfo, YoutubeVideo
 from .message import Message, PrivateMessage, MuteMessage, PinnedMessage
 
-VERSION = "0.12.0"
+VERSION = "0.13.0"
